==> org.opennms.features.gwt-suggestion-combobox-1.12.7.jar: org/opennms/features/gwt/combobox/client/view/NodeDetail.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2011-2012 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2012 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.features.gwt.combobox.client.view;

import com.google.gwt.core.client.JavaScriptObject;

public class NodeDetail extends JavaScriptObject {

    protected NodeDetail() {}
    
    public final native String getLabel() /*-{
        return this["@label"];
    }-*/;
    
    public final native int getId() /*-{
        return parseInt(this["@id"]);
    }-*/;
    
    public final native String getNodeType() /*-{
        return this["@type"];
    }-*/;
}

==> org.opennms.features.gwt-suggestion-combobox-19.0.0-20160718.200945-115.jar: org/opennms/features/gwt/combobox/client/view/NodeDetail.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2011-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.features.gwt.combobox.client.view;

import com.google.gwt.core.client.JavaScriptObject;

public class NodeDetail extends JavaScriptObject {

    protected NodeDetail() {}
    
    public final native String getLabel() /*-{
        return this.label;
    }-*/;
    
    public final native int getId() /*-{
        return parseInt(this.id);
    }-*/;
    
    public final native String getNodeType() /*-{
        return this.type;
    }-*/;
}
